==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/PMSCHEDULETOOLID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PMSCHEDULETOOLID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PMSCHEDULETOOLID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PPMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBPLANID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PMSCHEDULETOOLID_Type", propOrder = {
    "ppmid",
    "toolid",
    "activitycode",
    "jobplanid"
})
public class PMSCHEDULETOOLID_Type {

    @XmlElement(name = "PPMID", required = true)
    protected PPM_Type ppmid;
    @XmlElement(name = "TOOLID", required = true)
    protected TOOLID toolid;
    @XmlElement(name = "ACTIVITYCODE", required = true)
    protected ACTIVITYCODE activitycode;
    @XmlElement(name = "JOBPLANID")
    protected TASKLISTID_Type jobplanid;

    /**
     * Obtient la valeur de la propriété ppmid.
     * 
     * @return
     *     possible object is
     *     {@link PPM_Type }
     *     
     */
    public PPM_Type getPPMID() {
        return ppmid;
    }

    /**
     * Définit la valeur de la propriété ppmid.
     * 
     * @param value
     *     allowed object is
     *     {@link PPM_Type }
     *     
     */
    public void setPPMID(PPM_Type value) {
        this.ppmid = value;
    }

    /**
     * Obtient la valeur de la propriété toolid.
     * 
     * @return
     *     possible object is
     *     {@link TOOLID }
     *     
     */
    public TOOLID getTOOLID() {
        return toolid;
    }

    /**
     * Définit la valeur de la propriété toolid.
     * 
     * @param value
     *     allowed object is
     *     {@link TOOLID }
     *     
     */
    public void setTOOLID(TOOLID value) {
        this.toolid = value;
    }

    /**
     * Obtient la valeur de la propriété activitycode.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public ACTIVITYCODE getACTIVITYCODE() {
        return activitycode;
    }

    /**
     * Définit la valeur de la propriété activitycode.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public void setACTIVITYCODE(ACTIVITYCODE value) {
        this.activitycode = value;
    }

    /**
     * Obtient la valeur de la propriété jobplanid.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getJOBPLANID() {
        return jobplanid;
    }

    /**
     * Définit la valeur de la propriété jobplanid.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setJOBPLANID(TASKLISTID_Type value) {
        this.jobplanid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/PMSCHEDULETOOLID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PMSCHEDULETOOLID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PMSCHEDULETOOLID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PPMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOLID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBPLANID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PMSCHEDULETOOLID_Type", propOrder = {
    "ppmid",
    "toolid",
    "activitycode",
    "jobplanid"
})
public class PMSCHEDULETOOLID_Type {

    @XmlElement(name = "PPMID", required = true)
    protected PPM_Type ppmid;
    @XmlElement(name = "TOOLID", required = true)
    protected TOOLID toolid;
    @XmlElement(name = "ACTIVITYCODE", required = true)
    protected ACTIVITYCODE activitycode;
    @XmlElement(name = "JOBPLANID")
    protected TASKLISTID_Type jobplanid;

    /**
     * Gets the value of the ppmid property.
     * 
     * @return
     *     possible object is
     *     {@link PPM_Type }
     *     
     */
    public PPM_Type getPPMID() {
        return ppmid;
    }

    /**
     * Sets the value of the ppmid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PPM_Type }
     *     
     */
    public void setPPMID(PPM_Type value) {
        this.ppmid = value;
    }

    /**
     * Gets the value of the toolid property.
     * 
     * @return
     *     possible object is
     *     {@link TOOLID }
     *     
     */
    public TOOLID getTOOLID() {
        return toolid;
    }

    /**
     * Sets the value of the toolid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TOOLID }
     *     
     */
    public void setTOOLID(TOOLID value) {
        this.toolid = value;
    }

    /**
     * Gets the value of the activitycode property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public ACTIVITYCODE getACTIVITYCODE() {
        return activitycode;
    }

    /**
     * Sets the value of the activitycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public void setACTIVITYCODE(ACTIVITYCODE value) {
        this.activitycode = value;
    }

    /**
     * Gets the value of the jobplanid property.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getJOBPLANID() {
        return jobplanid;
    }

    /**
     * Sets the value of the jobplanid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setJOBPLANID(TASKLISTID_Type value) {
        this.jobplanid = value;
    }

}
